##  Monitor Progress Using Metrics
To monitor progress, use the following metrics on the onboarding dashboard for enterprise architects. For additional information, see [Understanding Best-Practice Metrics](https://help.sap.com/docs/leanix/ea/application-portfolio-management-onboarding-dashboard-for-enterprise-architects?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758a23c7a441014b785d6548482893a__understanding_best_practice_metrics).
Metrics for Fact Sheet Ownership Metric | Explanation
---|---
At least 20 applications* have a subscriber of type Responsible.  | Accurate, comprehensive, and up-to-date information in your inventory is crucial. Assigning fact sheet responsibility and ownership through subscriptions enables you to ensure information reliability.


*Count all application fact sheets where the subtype is business application or empty.
YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
